@@ -1,5 +1,5 @@
 context("DGEobj.utils - tests for runQvalue.R functions")
-skip_on_cran()
+skip_if(setup_failed)
 
 
 test_that("runQvalue.R: runQvalue()", {
